TopGenesSVM: Selection of top ranked (differentially expressed) genes...

Description Usage Arguments Details Value Author(s) Examples

View source: R/TopGenesSVM.R

Description

The function returns the list of top ranked genes of specified size selected through Support Vector Machine (SVM) method.

Usage

1
TopGenesSVM(x, y, n)

Arguments

x

Nxp data frame of gene expression values, where, N represents number of genes and p represents samples/time points generated in a case vs. control gene expression study.

y

px1 numeric vector with entries 1 and -1 representing sample/subject labels, where 1 and -1 represents the labels of subjects/ samples for case and control condition respectively.

n

Numeric constant (< N) representing the number of top ranked genes to be selected from the gene expression data.

Details

Selection of the top ranked (differentially expressed) genes through SVM method.

Selects the top ranked (differentially expressed) genes of specified size through SVM method. Take the gene expression data matrix (rows as genes and coloumns as samples) and vector of class labels of subjects (1: case and -1: control) as inputs.

Value

A list of differentially expressed specified number of genes through SVM method.

Author(s)

Samarendra Das <samarendra4849 at gmail.com>

Examples

1
2
3
4
5
x=as.data.frame(matrix(runif(1000), 50))
row.names(x) = paste("Gene", 1:50)
colnames(x) = paste("Samp", 1:20)
y=as.numeric(c(rep(1, 10), rep(-1, 10)))
TopGenesSVM(x, y, n=5)

sam-uofl/BSM documentation built on Sept. 6, 2020, 12:09 a.m.