weightmr: Computation of gene ranking weights through Maximum Relevance...

Description Usage Arguments Details Value Author(s) References Examples

Description

The function computes weights for features (e.g. genes) using Maximum Relevance and Minimum Redundancy (MRMR) technique and also produce the ranked genelist based on the computed weights.

Usage

1
weightmr(x, y)

Arguments

x

Nxp data frame of gene expression values, where, N represents number of genes and p represents samples/time points generated in a case vs. control gene expression study.

y

px1 numeric vector with entries 1 and -1 representing sample/subject labels, where 1 and -1 represents the labels of subjects/ samples for case and control conditions respectively.

Details

Computation of gene ranking weights through Maximum Relevance and Minimum Redundancy (MRMR) method.

Value

A vector of weights computed through MRMR method and a complete ranked gene list.

Author(s)

Samarendra Das <samarendra4849 at gmail.com>

References

Feature selection based on mutual information: criteria of max-dependency, max-relevance and min-redundancy. IEEE Trans. Pattern Anal. Mach. Intell., 27 (8) 1226-1238. DOI: 10.1109/TPAMI.2005.159.

Examples

1
2
3
4
5
x=as.data.frame(matrix(runif(1000), 50))
row.names(x) = paste("Gene", 1:50)
colnames(x) = paste("Samp", 1:20)
y=as.numeric(c(rep(1, 10), rep(-1, 10)))
weightmr(x, y)

sam-uofl/BSM documentation built on Sept. 6, 2020, 12:09 a.m.