weightsvm: Computation of weights for gene selection through SVM...

Description Usage Arguments Value Author(s) References Examples

Description

computes weights for features (e.g. genes) using Support Vector Machine (SVM) method and also produce the ranked genelist based on the computed weights.

Usage

1
weightsvm(x, y)

Arguments

x

Nxp data frame of gene expression values, where, N represents number of genes and p represents samples/time points generated in a case vs. control gene expression study.

y

px1 numeric vector with entries 1 and -1 representing sample/subject labels, where 1 and -1 represents the labels of subjects/ samples for case and control condition respectively.

Value

A vector of weights computed through SVM method and a complete ranked gene list.

Author(s)

Samarendra Das <samarendra4849 at gmail.com>

References

Guyon et al. (2002). Gene selection for cancer classification using support vector machines. Mach. Learn., 46, 389-422

Examples

1
2
3
4
5
x=as.data.frame(matrix(runif(1000), 50))
row.names(x) = paste("Gene", 1:50)
colnames(x) = paste("Samp", 1:20)
y=as.numeric(c(rep(1, 10), rep(-1, 10)))
weightsvm(x, y)

sam-uofl/BSM documentation built on Sept. 6, 2020, 12:09 a.m.