Description Usage Arguments Details Value Author(s) References Examples
The function computes weights for features (e.g. genes) using Maximum Relevance and Minimum Redundancy (MRMR) technique and also produce the ranked genelist based on the computed weights.
1 | weightmr(x, y)
|
x |
Nxp data frame of gene expression values, where, N represents number of genes and p represents samples/time points generated in a case vs. control gene expression study. |
y |
px1 numeric vector with entries 1 and -1 representing sample/subject labels, where 1 and -1 represents the labels of subjects/ samples for case and control conditions respectively. |
Computation of gene ranking weights through Maximum Relevance and Minimum Redundancy (MRMR) method.
A vector of weights computed through MRMR method and a complete ranked gene list.
Samarendra Das <samarendra4849 at gmail.com>
Feature selection based on mutual information: criteria of max-dependency, max-relevance and min-redundancy. IEEE Trans. Pattern Anal. Mach. Intell., 27 (8) 1226-1238. DOI: 10.1109/TPAMI.2005.159.
1 2 3 4 5 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.