Description Usage Arguments Value Author(s) References Examples
computes weights for features (e.g. genes) using Support Vector Machine (SVM) method and also produce the ranked genelist based on the computed weights.
1 | weightsvm(x, y)
|
x |
Nxp data frame of gene expression values, where, N represents number of genes and p represents samples/time points generated in a case vs. control gene expression study. |
y |
px1 numeric vector with entries 1 and -1 representing sample/subject labels, where 1 and -1 represents the labels of subjects/ samples for case and control condition respectively. |
A vector of weights computed through SVM method and a complete ranked gene list.
Samarendra Das <samarendra4849 at gmail.com>
Guyon et al. (2002). Gene selection for cancer classification using support vector machines. Mach. Learn., 46, 389-422
1 2 3 4 5 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.